/**********************************************************************
** Copyright (C) 2000 Trolltech AS.  All rights reserved.
**
** This file is part of TQt Designer.
**
** This file may be distributed and/or modified under the terms of the
** GNU General Public License version 2 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
**
** See http://www.trolltech.com/gpl/ for GPL licensing information.
**
** Contact info@trolltech.com if any conditions of this licensing are
** not clear to you.
**
**********************************************************************/

#ifndef __previewframe_h__
#define __previewframe_h__

#include <tqvbox.h>
#include <tqworkspace.h>

#include "previewwidgetimpl.h"

class PreviewWorkspace : public TQWorkspace
{
    TQ_OBJECT
  
public:
    PreviewWorkspace( TQWidget* parent = 0, const char* name = 0 )
        : TQWorkspace( parent, name ) {}
    ~PreviewWorkspace() {}

protected:
    void paintEvent( TQPaintEvent* );
};

class PreviewFrame : public TQVBox
{
    TQ_OBJECT
  

public:
    PreviewFrame( TQWidget *parent = 0, const char *name = 0 );
    void setPreviewPalette(TQPalette);

private:
    PreviewWidget 	*previewWidget;
};

#endif
